@@ -219,9 +219,10 @@ static const char description[] = I18N_NOOP( "The KDevelop Integrated Developmen
                 }
             }
 
-            KUrl f(file);
-            if( f.isRelative() )
-                f=KUrl(QDir::currentPath(), file);
+            if( QFileInfo( file ).isRelative() ) {
+                file = QDir::currentPath() + QDir::separator() + file;
+            }
+            KUrl f("file://"+file);
 
             if(!core->documentController()->openDocument(f, line))
                 kWarning() << i18n("Could not open %1") << args->arg(i);
