@@ -693,6 +693,9 @@ bool CodeCompletionContext::doConstructorCompletion() {
   QString text = m_text.trimmed();
   LOCKDUCHAIN;
 
+  if(!m_duContext)
+    return false;
+
   QStringList hadItems;
   
   text = text.trimmed();
@@ -1206,8 +1209,6 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::completionItems(bool& sh
                   if(memberAccessOperation() != Cpp::CodeCompletionContext::StaticMemberChoose) {
                     if(decl.first->kind() != Declaration::Instance && decl.first->kind() != Declaration::Alias)
                       continue;
-                    if(classMember && classMember->isStatic())
-                      continue; //Skip static class members when not doing static access
                     if(decl.first->abstractType().cast<EnumeratorType>())
                       continue; //Skip enumerators
                   }else{
@@ -1526,7 +1527,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::getImplementationHelpers
   foreach(Declaration* decl, context->localDeclarations()) {
     ClassFunctionDeclaration* classFun = dynamic_cast<ClassFunctionDeclaration*>(decl);
     AbstractFunctionDeclaration* funDecl = dynamic_cast<AbstractFunctionDeclaration*>(decl);
-    if(funDecl && (!classFun || !classFun->isAbstract()) && !decl->isDefinition() && !FunctionDefinition::definition(decl) && decl->qualifiedIdentifier().toString().startsWith(minimumScope.toString()))
+    if(funDecl  && !decl->range().isEmpty() && (!classFun || (!classFun->isAbstract() && !classFun->isSignal())) && !decl->isDefinition() && !FunctionDefinition::definition(decl) && decl->qualifiedIdentifier().toString().startsWith(minimumScope.toString()))
       ret << KDevelop::CompletionTreeItemPointer(new ImplementationHelperItem(ImplementationHelperItem::CreateDefinition, DeclarationPointer(decl), KSharedPtr<CodeCompletionContext>(this)));
   }
 
