@@ -218,7 +218,7 @@ void IncludePathComputer::computeBackground() {
                         p->setSource(KDevelop::ProblemData::Preprocessor);
                         p->setDescription(i18n("Build manager did not return an include path" ));
                         p->setExplanation(i18n("The build manager did not return the include path %1, which could be resolved by the include path resolver", r.pathOrUrl()));
-                        p->setFinalLocation(DocumentRange(m_source.pathOrUrl(), KTextEditor::Cursor(0,0), KTextEditor::Cursor(0,0)));
+                        p->setFinalLocation(DocumentRange(m_source.pathOrUrl(), KTextEditor::Range::invalid()));
                         *m_problems << p;
                       }
                   }
