@@ -126,13 +126,18 @@ KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size
   KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size > ret;
   ret.resize(index_size);
   #define ADD_TOKEN(string) ret[KDevelop::IndexedString(#string).index() % index_size].append(qMakePair(KDevelop::IndexedString(#string).index(), Token_ ## string));
+  #define ADD_TOKEN2(string, tok) ret[KDevelop::IndexedString(#string).index() % index_size].append(qMakePair(KDevelop::IndexedString(#string).index(), Token_ ## tok));
   ADD_TOKEN(K_DCOP);
   ADD_TOKEN(Q_OBJECT);
   ADD_TOKEN(__attribute__);
   ADD_TOKEN(__typeof);
+  ADD_TOKEN2(__typeof__, __typeof);
+  ADD_TOKEN2(typeof, __typeof);
   ADD_TOKEN(and);
   ADD_TOKEN(and_eq);
   ADD_TOKEN(asm);
+  ADD_TOKEN2(__asm, asm);
+  ADD_TOKEN2(__asm__, asm)
   ADD_TOKEN(auto);
   ADD_TOKEN(bitand);
   ADD_TOKEN(bitor);
@@ -163,7 +168,6 @@ KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size
   ADD_TOKEN(friend);
   ADD_TOKEN(goto);
   ADD_TOKEN(if);
-  ADD_TOKEN(incr);
   ADD_TOKEN(inline);
   ADD_TOKEN(int);
   ADD_TOKEN(k_dcop);
@@ -206,6 +210,7 @@ KDevVarLengthArray<KDevVarLengthArray<QPair<uint, TOKEN_KIND>, 10 >, index_size
   ADD_TOKEN(virtual);
   ADD_TOKEN(void);
   ADD_TOKEN(volatile);
+  ADD_TOKEN2(__volatile__, volatile);
   ADD_TOKEN(wchar_t);
   ADD_TOKEN(while);
   ADD_TOKEN(xor);
