@@ -407,6 +407,55 @@ private slots:
     dumper.dump(ast, lastSession->token_stream);
   }
 
+  void testInitListTrailingComma()
+  {
+    //see bug https://bugs.kde.org/show_bug.cgi?id=233328
+
+    QByteArray code("const int foo [] = {1,};");
+    pool memPool;
+    TranslationUnitAST* ast = parse(code, &memPool);
+    dumper.dump(ast, lastSession->token_stream);
+
+    QCOMPARE(ast->declarations->count(), 1);
+    SimpleDeclarationAST* simpleDecl = reinterpret_cast<SimpleDeclarationAST*>(ast->declarations->at(0)->element);
+    QVERIFY(simpleDecl);
+
+    QCOMPARE(simpleDecl->init_declarators->count(), 1);
+    
+  }
+
+  void testAsmVolatile()
+  {
+    //see bug https://bugs.kde.org/show_bug.cgi?id=238772
+    QByteArray code("__asm__ __volatile__ (\"cld; rep; \" \"stosq\" : \"=c\""
+                    "  (__d0), \"=D\" (__d1) : \"a\" (0), \"0\" (sizeof (fd_set) / sizeof (__fd_mask)),"
+                    "  \"1\""
+                    "  (&((&rfds)->__fds_bits)[0]) : \"memory\");");
+    pool memPool;
+    TranslationUnitAST* ast = parse(code, &memPool);
+    dumper.dump(ast, lastSession->token_stream);
+
+    QCOMPARE(ast->declarations->count(), 1);
+    AsmDefinitionAST* asmDecl = reinterpret_cast<AsmDefinitionAST*>(ast->declarations->at(0)->element);
+    QVERIFY(asmDecl);
+
+    QCOMPARE(asmDecl->cv->count(), 1);
+    QVERIFY(lastSession->token_stream->kind(asmDecl->cv->at(0)->element) == Token_volatile);
+  }
+
+  void testIncrIdentifier()
+  {
+    //see bug https://bugs.kde.org/show_bug.cgi?id=238772
+    QByteArray code("void incr();");
+    pool memPool;
+    TranslationUnitAST* ast = parse(code, &memPool);
+    dumper.dump(ast, lastSession->token_stream);
+
+    QCOMPARE(ast->declarations->count(), 1);
+    FunctionDefinitionAST* funcDecl = reinterpret_cast<FunctionDefinitionAST*>(ast->declarations->at(0)->element);
+    QVERIFY(funcDecl);
+  }
+
   /*void testParseFile()
   {
      QFile file(TEST_FILE);
