@@ -50,7 +50,7 @@ QString CMakeFunctionArgument::unescapeValue(const QString& value)
     
     QString newValue;
     int last=0;
-    for(int i=firstScape; i<value.size() && i>=0; i=value.indexOf(scapingChar, i+2))
+    for(int i=firstScape; i<value.size()-1 && i>=0; i=value.indexOf(scapingChar, i+2))
     {
         newValue+=value.mid(last, i-last);
         QChar current=value[i+1];
@@ -277,6 +277,7 @@ CMakeFileContent CMakeListsParser::readCMakeFile(const QString & fileName)
         return CMakeFileContent();
     if ( !cmListFileLexer_SetFileName( lexer, qPrintable( fileName ) ) ) {
         kDebug(9042) << "cmake read error. could not read " << fileName;
+        cmListFileLexer_Delete(lexer);
         return CMakeFileContent();
     }
 
@@ -313,6 +314,7 @@ CMakeFileContent CMakeListsParser::readCMakeFile(const QString & fileName)
             }
         }
     }
+    cmListFileLexer_Delete(lexer);
 
     return ret;
 }
