@@ -84,7 +84,7 @@ QList< CMakeProjectVisitor::IntPair > CMakeProjectVisitor::parseArgument(const Q
     bool gotDollar=false;
     for(int i=exp.indexOf('$'); i<exp.size(); i++)
     {
-        switch(exp[i].toAscii())
+        switch(exp[i].unicode())
         {
             case '$':
                 gotDollar=true;
@@ -274,12 +274,23 @@ int CMakeProjectVisitor::visit( const SetTargetPropsAst * targetProps)
     {
         foreach(const SetTargetPropsAst::PropPair& t, targetProps->properties())
         {
-            m_props[TargetProperty][tname][t.first] += t.second;
+            m_props[TargetProperty][tname][t.first] = t.second.split(';');
         }
     }
     return 1;
 }
 
+int CMakeProjectVisitor::visit( const SetDirectoryPropsAst * dirProps)
+{   
+    QString dir=m_vars->value("CMAKE_CURRENT_SOURCE_DIR").join(QString());
+    kDebug(9042) << "setting directory props for " << dirProps->properties() << dir;
+    foreach(const SetDirectoryPropsAst::PropPair& t, dirProps->properties())
+    {
+        m_props[DirectoryProperty][dir][t.first] = t.second.split(';');
+    }
+    return 1;
+}
+
 int CMakeProjectVisitor::visit( const GetTargetPropAst * prop)
 {
     kDebug(9042) << "getting target " << prop->target() << " prop " << prop->property() << prop->variableName();
@@ -290,9 +301,9 @@ int CMakeProjectVisitor::visit( const GetTargetPropAst * prop)
 //         kDebug(9032) << "unexistent property" << prop->property() << "on" << prop->target();
     }
 //     kDebug(9042) << "current properties" << m_props[TargetProperty][prop->target()].keys();
-//     kDebug(9042) << "goooooot" << m_props[TargetProperty][prop->target()][prop->property()];
     
     m_vars->insert(prop->variableName(), m_props[TargetProperty][prop->target()][prop->property()]);
+//     kDebug(9042) << "goooooot" << m_vars->value(prop->variableName());
     return 1;
 }
 
@@ -301,16 +312,30 @@ int CMakeProjectVisitor::visit(const AddSubdirectoryAst *subd)
     kDebug(9042) << "adding subdirectory" << subd->sourceDir();
 
     VisitorState p=stackTop();
-    m_folderDesc[subd->sourceDir()]=p.code->at(p.line);
 
-    m_subdirectories += subd->sourceDir();
+    Subdirectory d;
+    d.name=subd->sourceDir();
+    d.build_dir=subd->binaryDir().isEmpty() ? d.name : subd->binaryDir();
+    d.desc=p.code->at(p.line);
+    
+    m_subdirectories += d;
     return 1;
 }
 
 int CMakeProjectVisitor::visit(const SubdirsAst *sdirs)
 {
     kDebug(9042) << "adding subdirectories" << sdirs->directories() << sdirs->exluceFromAll();
-    m_subdirectories += sdirs->directories() << sdirs->exluceFromAll();
+    VisitorState p=stackTop();
+    CMakeFunctionDesc desc=p.code->at(p.line);
+    
+    foreach(const QString& dir, sdirs->directories() + sdirs->exluceFromAll()) {
+        Subdirectory d;
+        d.name=dir;
+        d.build_dir=dir;
+        d.desc=desc;
+        
+        m_subdirectories += d;
+    }
     return 1;
 }
 
@@ -367,6 +392,20 @@ void CMakeProjectVisitor::defineTarget(const QString& id, const QStringList& sou
     target.desc=p.code->at(p.line);
     
     m_targetForId[id]=target;
+
+    QString exe=id;
+    switch(t) {
+        case Target::Executable:
+            exe += m_vars->value("CMAKE_EXECUTABLE_SUFFIX").join(QString());
+            break;
+        case Target::Library:
+            exe = QString("%1%2%3").arg(m_vars->value("CMAKE_LIBRARY_PREFIX").join(QString())).arg(id).arg(m_vars->value("CMAKE_LIBRARY_SUFFIX").join(QString()));
+            break;
+        case Target::Custom:
+            break;
+    }
+    
+    m_props[TargetProperty][id]["LOCATION"]=QStringList(m_vars->value("CMAKE_CURRENT_BINARY_DIR").join(QString())+'/'+exe);
 }
 
 int CMakeProjectVisitor::visit(const AddExecutableAst *exec)
@@ -518,55 +557,66 @@ int CMakeProjectVisitor::visit(const FindPackageAst *pack)
 {
     if(!haveToFind(pack->name()))
         return 1;
-    QStringList modulePath = m_vars->value("CMAKE_MODULE_PATH") + m_modulePath;
+    const QStringList modulePath = m_vars->value("CMAKE_MODULE_PATH") + m_modulePath;
     kDebug(9042) << "Find:" << pack->name() << "package." << m_modulePath << "No module: " << pack->noModule();
 
-    QStringList possibs;
-    if(pack->noModule())
-    {
-        QString var="CMAKE_INSTALL_PREFIX";
-        QString instPath;
-        if(m_vars->contains(var))
-            instPath = m_vars->value(var).join(QString());
-        else if(m_cache->contains(var))
-            instPath = m_cache->value(var).value;
-
-         kDebug(9042) << "config mode" << m_vars->value(var).join(QString()) << m_cache->value(var).value << instPath;
-
-#if defined(Q_OS_WIN)
-        modulePath.prepend(instPath);
-        modulePath.prepend(instPath+"/cmake");
-#endif
-        QString name=pack->name();
-        QStringList postfix=QStringList() << QString() << "/cmake" << "/CMake";
-        foreach(const QString& post, postfix)
-        {
-            modulePath.prepend(instPath+"/share/"+name.toLower()+post);
-            modulePath.prepend(instPath+"/lib/"+name.toLower()+post);
-        }
-        
-        QString varName=pack->name()+"_DIR";
-        if(m_cache->contains(varName))
-            modulePath.prepend(m_cache->value(varName).value);
-
-        possibs+=QString("%1Config.cmake").arg(pack->name());
-        possibs+=QString("%1-config.cmake").arg(pack->name().toLower());
-    }
-    else
+    QStringList possibleModuleNames;
+    if(!pack->noModule()) //TODO Also implied by a whole slew of additional options.
     {
+        // Look for a Find{package}.cmake
         QString possib=pack->name();
         if(!possib.endsWith(".cmake"))
             possib += ".cmake";
         possib.prepend("Find");
-        possibs += possib;
+        possibleModuleNames += possib;
     }
 
+    QString var="CMAKE_INSTALL_PREFIX";
+    QString instPath;
+    if(m_vars->contains(var))
+        instPath = m_vars->value(var).join(QString());
+    else if(m_cache->contains(var))
+        instPath = m_cache->value(var).value;
+
+    kDebug(9042) << "config mode" << m_vars->value(var).join(QString()) << m_cache->value(var).value << instPath;
+
+    #if defined(Q_OS_WIN)
+    modulePath.prepend(instPath);
+    modulePath.prepend(instPath+"/cmake");
+    #endif
+    QString name=pack->name();
+    QStringList postfix=QStringList() << QString() << "/cmake" << "/CMake";
+    QStringList configPath;
+    foreach(const QString& post, postfix)
+    {
+        configPath.prepend(instPath+"/share/"+name.toLower()+post);
+        configPath.prepend(instPath+"/lib/"+name.toLower()+post);
+    }
+
+    QString varName=pack->name()+"_DIR";
+    if(m_cache->contains(varName))
+        configPath.prepend(m_cache->value(varName).value);
+
+    QStringList possibleConfigNames;
+    possibleConfigNames+=QString("%1Config.cmake").arg(pack->name());
+    possibleConfigNames+=QString("%1-config.cmake").arg(pack->name().toLower());
+
     QString path;
-    foreach(const QString& possib, possibs)
+    foreach(const QString& possib, possibleModuleNames)
     {
         path=findFile(possib, modulePath);
-        if(!path.isEmpty())
+        if(!path.isEmpty()) {
             break;
+        }
+    }
+    if (path.isEmpty()) {
+        foreach(const QString& possib, possibleConfigNames) {
+            path = findFile(possib, configPath);
+            if (!path.isEmpty()) {
+                m_vars->insert(pack->name()+"_DIR", QStringList(KUrl(path).directory()));
+                break;
+            }
+        }
     }
 
     if(!path.isEmpty())
@@ -594,10 +644,13 @@ int CMakeProjectVisitor::visit(const FindPackageAst *pack)
         }
         m_vars->take("CMAKE_CURRENT_LIST_FILE");
     }
-    else if(pack->isRequired())
+    else
     {
-        //FIXME: Put here the error.
-        kDebug(9032) << "error: Could not find" << pack->name() << "into" << modulePath;
+        if(pack->isRequired()) {
+            //FIXME: Put here the error.
+            kDebug(9032) << "error: Could not find" << pack->name() << "into" << modulePath;
+        }
+        m_vars->insert(QString("%1_DIR").arg(pack->name()), QStringList(QString("%1_DIR-NOTFOUND").arg(pack->name())));
     }
     kDebug(9042) << "Exit. Found:" << pack->name() << m_vars->value(pack->name()+"_FOUND");
 
@@ -1860,6 +1913,8 @@ int CMakeProjectVisitor::visit(const MarkAsAdvancedAst *maa)
     return 1;
 }
 
+/// @todo Add support for platform-specific argument splitting
+/// (UNIX_COMMAND and WINDOWS_COMMAND) introduced in CMake 2.8.
 int CMakeProjectVisitor::visit( const SeparateArgumentsAst * separgs )
 {
     QString varName=separgs->variableName();
@@ -1868,6 +1923,7 @@ int CMakeProjectVisitor::visit( const SeparateArgumentsAst * separgs )
     {
         res += value.split(' ');
     }
+    m_vars->insert(separgs->variableName(), res);
     return 1;
 }
 
@@ -1925,12 +1981,15 @@ int CMakeProjectVisitor::visit( const WhileAst * whileast)
     usesForArguments(whileast->condition(), cond.variableArguments(), m_topctx, whileast->content()[whileast->line()]);
 
     kDebug(9042) << "Visiting While" << whileast->condition() << "?" << result;
+    int end=whileast->line()+1;
     if(result)
     {
-        walk(whileast->content(), whileast->line()+1);
-        walk(whileast->content(), whileast->line());
+        end=walk(whileast->content(), whileast->line()+1);
+        if(end<whileast->content().size() && whileast->content()[end].name.toUpper()!="BREAK") {
+            walk(whileast->content(), whileast->line());
+        }
     }
-    CMakeFileContent::const_iterator it=whileast->content().constBegin()+whileast->line()+1;
+    CMakeFileContent::const_iterator it=whileast->content().constBegin()+end;
     CMakeFileContent::const_iterator itEnd=whileast->content().constEnd();
     int lines=0, inside=1;
     for(; inside>0 && it!=itEnd; ++it, lines++)
@@ -1968,12 +2027,13 @@ enum RecursivityType { No, Yes, End };
 
 RecursivityType recursivity(const QString& functionName)
 {
-    if(functionName.toUpper()=="IF" || functionName.toUpper()=="WHILE" ||
-       functionName.toUpper()=="FOREACH" || functionName.toUpper()=="MACRO")
+    QString upperFunctioName=functionName.toUpper();
+    if(upperFunctioName=="IF" || upperFunctioName=="WHILE" ||
+       upperFunctioName=="FOREACH" || upperFunctioName=="MACRO")
         return Yes;
-    else if(functionName.toUpper()=="ELSE" || functionName.toUpper()=="ELSEIF")
+    else if(upperFunctioName=="ELSE" || upperFunctioName=="ELSEIF")
         return End;
-    else if(functionName.toUpper().startsWith("END"))
+    else if(upperFunctioName.startsWith("END") || upperFunctioName=="BREAK")
         return End;
     return No;
 }
@@ -2032,7 +2092,9 @@ int CMakeProjectVisitor::walk(const CMakeFileContent & fc, int line, bool isClea
             m_backtrace.pop();
             m_topctx=aux;
             return line;
-        }
+        } else if(r==Yes)
+            m_loopType.push(func.name.toUpper());
+        
         if(element->isDeprecated()) {
             kDebug(9032) << "Warning: Using the function: " << func.name << " which is deprecated by cmake.";
             DUChainWriteLocker lock(DUChain::lock());
